@@ -11,8 +11,9 @@ class Combiner(object):
         self.options = options
 
     def combine(self, page_file_names):
-        logger.info("combine %d files into %s", len(page_file_names), self.options.output_file_name)
+        output_file_name = self.options.output_file_name[0]
+        logger.info("combine %d files into %s", len(page_file_names), output_file_name)
         combine_args = ['pdftk']
         combine_args += page_file_names
-        combine_args += ['output', os.path.basename(self.options.output_file_name), 'compress']
+        combine_args += ['output', os.path.basename(output_file_name), 'compress']
         return subprocess.call(combine_args)
